Error types for CUE evaluation
This module provides standalone error types for the cuengine crate, allowing it to be used independently of the cuenv ecosystem.
Enums
- CueEngine
Error - Errors that can occur during CUE evaluation
Type Aliases
- Result
- Result type for CUE evaluation operations